@@ -11,7 +11,7 @@
 // ==========================================================================
 //
 // Dynamic Multi-Homing Setup (DynMHS)
-// Copyright (C) 2024-2025 by Thomas Dreibholz
+// Copyright (C) 2024-2026 by Thomas Dreibholz
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -776,7 +776,7 @@ int main(int argc, char** argv)
       ( "logcolor,Z",
            boost::program_options::value<bool>(&logColor)->default_value(true),
            "Use ANSI color escape sequences for log output" )
-      ( "verbose,v",
+      ( "verbose,!",
            boost::program_options::value<unsigned int>(&logLevel)->implicit_value(boost::log::trivial::severity_level::trace),
            "Verbose logging level" )
       ( "quiet,q",
